@@ -14,7 +14,10 @@ import aws_cdk._jsii
 import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
-    "cdk-image-pipeline", "0.1.6", __name__[0:-6], "cdk-image-pipeline@0.1.6.jsii.tgz"
+    "cdk-image-pipeline",
+    "0.1.14",
+    __name__[0:-6],
+    "cdk-image-pipeline@0.1.14.jsii.tgz",
 )
 
 __all__ = [
